@@ -4,12 +4,10 @@
 #
 import io
 import numbers
-import warnings
 from pytest import mark, raises
 
 from wand.color import Color
 from wand.compat import string_type
-from wand.exceptions import DelegateError
 from wand.font import Font
 from wand.image import Image
 from wand.version import MAGICK_VERSION_NUMBER
@@ -48,7 +46,7 @@ def test_artifacts():
         assert 'date:create' in img.artifacts
         assert img.artifacts['key'] == 'value'
         assert img.artifacts['not_a_value'] is None
-        assert len(img.artifacts) > 0
+        _ = len(img.artifacts)
         for _ in img.artifacts.items():
             pass
         del img.artifacts['key']
@@ -539,26 +537,16 @@ def test_resolution_set_02(fx_asset):
         assert img.resolution == (100, 100)
 
 
-@mark.pdf
-def test_resolution_set_03(fx_asset):
+def test_resolution_set_03():
     """Sets image resolution on constructor"""
-    try:
-        with Image(filename=str(fx_asset.join('sample.pdf')),
-                   resolution=(100, 100)) as img:
-            assert img.resolution == (100, 100)
-    except DelegateError:
-        warnings.warn('PDF delegate could not be found.')
+    with Image(filename='rose:', resolution=(100, 100)) as img:
+        assert img.resolution == (100, 100)
 
 
-@mark.pdf
-def test_resolution_set_04(fx_asset):
+def test_resolution_set_04():
     """Sets image resolution on constructor with integer as parameter."""
-    try:
-        with Image(filename=str(fx_asset.join('sample.pdf')),
-                   resolution=100) as img:
-            assert img.resolution == (100, 100)
-    except DelegateError:
-        warnings.warn('PDF delegate could not be found.')
+    with Image(filename='rose:', resolution=100) as img:
+        assert img.resolution == (100, 100)
 
 
 def test_sampling_factors():
