@@ -127,14 +127,11 @@ def test_read_from_unicode_filename(fx_asset, tmpdir):
         assert img.width == 402
 
 
-@mark.pdf
 def test_read_with_colorspace(fx_asset):
-    fpath = str(fx_asset.join('cmyka.pdf'))
+    fpath = str(fx_asset.join('cmyk.jpg'))
     with Image(filename=fpath,
-               resolution=100,
                colorspace='srgb',
                units='pixelspercentimeter') as img:
-        assert img.colorspace == 'srgb'
         assert img.units == 'pixelspercentimeter'
 
 
@@ -224,6 +221,45 @@ def test_clone(fx_asset):
         img.wand
 
 
+def test_image_add():
+    with Image(filename='rose:') as a:
+        with Image(filename='rose:') as b:
+            a.image_add(b)
+        assert a.iterator_length() == 2
+    with raises(TypeError):
+        with Image(filename='rose:') as img:
+            img.image_add(0xdeadbeef)
+
+
+def test_image_get():
+    with Image(filename='rose:') as img:
+        with img.image_get() as i:
+            assert isinstance(i, Image)
+
+
+def test_image_remove():
+    with Image(filename='null:') as empty:
+        empty.image_remove()
+        assert empty.iterator_length() == 0
+
+
+def test_image_set():
+    with Image(filename='null:') as a:
+        with Image(filename='rose:') as b:
+            a.image_set(b)
+        assert a.iterator_length() == 1
+
+
+def test_image_swap():
+    with Image(width=1, height=1, background='red') as a:
+        a.read(filename='xc:green')
+        a.read(filename='xc:blue')
+        was = a.iterator_get()
+        a.image_swap(0, 2)
+        assert a.iterator_get() == was
+    with raises(TypeError):
+        a.image_swap('a', 'b')
+
 def test_ping_from_filename(fx_asset):
     file_path = str(fx_asset.join('mona-lisa.jpg'))
     with Image.ping(filename=file_path) as img:
